#include <komparediff2/komparediff2_export.h>

#if KOMPAREDIFF2_ENABLE_DEPRECATED_SINCE(5, 4)
#   include "diff2_export_p.h"
#   include <komparediff2/difference.h>
#   if KOMPAREDIFF2_DEPRECATED_WARNINGS_SINCE >= 0x050400
#       pragma message("Deprecated header. Since 5.4, use #include <KompareDiff2/Difference> instead")
#   endif
#else
#   error "Include of deprecated header is disabled"
#endif
