// This file was generated by ecm_setup_version(): DO NOT EDIT!

#ifndef KOMPAREDIFF2_VERSION_H
#define KOMPAREDIFF2_VERSION_H

#define KOMPAREDIFF2_VERSION_STRING "5.4.0"
#define KOMPAREDIFF2_VERSION_MAJOR 5
#define KOMPAREDIFF2_VERSION_MINOR 4
#define KOMPAREDIFF2_VERSION_PATCH 0
#define KOMPAREDIFF2_VERSION ((5<<16)|(4<<8)|(0))

#endif
